import Taro from '@tarojs/taro'
import useLike from "@/utils/hooks/useLike"
import { View, Text } from '@tarojs/components'
import formatPrice from "@/utils/formatPrice";
import Star from '@/components/Star/Star.jsx'
import position from '@/assets/icons/GuideCheck/position_logo.png'
import SeeDetails from '@/assets/icons/GuideCheck/SeeDetails.png'
import Attractions from '@/assets/icons/GuideCheck/Attractions.png'
import baozan from '@/assets/icons/housemantj/bgood.png'
import weibaozan from '@/assets/icons/housemantj/unLike.png'
import food from '@/assets/icons/ProCard/food.png'
import ProCard_hot from '@/assets/icons/ProCard/ProCard_hot.png'

import CouponCard from '@/components/CouponCard'
import Location from '@/components/Location'
import './style.less'


const CouponMedia = CouponCard.Media
const Action = CouponCard.Action
export default (props) => {
  const { item, cardNavigateTo } = props
  const [isLike, toggleLike] = useLike(item.isLike, 'tourist', item.targetId)

  const targetType = item.targetType

  const star = parseFloat(((item.sweetScore + item.environmentScore + item.serviceScore) / 3).toFixed(1));

  const handleDetail = () => {
    targetType=="shop_package"? Taro.navigateTo({ url: `/pages/details/foodDetails/foodDetails?id=${item.shopId}` })
    :targetType=="tourist"?Taro.navigateTo({ url: `/pages/details/mjDetails/sceneryDetails?id=${item.targetId}` })
    :Taro.navigateTo({ url: `/pages/details/foodDetails/foodDetails?id=${item.targetId}` })
  }

  const PayAction = <Action.Icon icon={SeeDetails} text='查看详情' onClick={handleDetail} />

  return (

    <View className='View-box-LR'>
      <View className='left-View-box'>
        {
          targetType === "shop_package" && (
            <View style={{ margin: '15px 5px' }}>
              <CouponCard action={PayAction}>
                <CouponMedia>
                  <CouponMedia.Header
                    cashback={item.cashback}
                    image={item.poster}
                    badge='food'
                  />
                  <CouponMedia.Body star={star}>
                    <View className='cpn-card-text'>
                      {(item.title).toString().length > 25 ? (item.title).substring(0, 25) + '...' : (item.title)}
                    </View>
                    <View className='cpn-card-text' style={{ marginTop: '10rpx' }}>
                      <Text className='cpn-card-text_mn'>￥{`${(item.actualPrice / 100)?.toFixed(2)}元`}</Text>
                      <Text className='cpn-card-text_rm'>{`门市价${(item.standardPrice / 100)?.toFixed(2)}元`}</Text>
                    </View>
                    <View className='cpn-md-act'>
                      <Location {...item} />
                    </View>
                  </CouponMedia.Body>
                </CouponMedia>
              </CouponCard>
            </View>
          )
        }
      </View>
      <View className='right-View-box'>
        {
          targetType !== "shop_package" && (

            <View style={{ margin: '15px 5px' }}>
              <CouponCard action={PayAction}>
                <CouponMedia>
                  <CouponMedia.Header
                    image={item.poster}
                    badge={targetType}
                  />
                  <CouponMedia.Body >
                    <View className='cpn-card-text'>
                      {(item.title).toString().length > 25 ? (item.title).substring(0, 25) + '...' : (item.title)}
                    </View>
                    <View className='cpn-card-text' style={{ marginTop: '10rpx' }}>
                      <Text className='cpn-card-text_mn'>￥{`${formatPrice(item.averagePrice)}元`}</Text>
                    </View>
                   
                    <View className='cpn-md-act'> 
                    <Location {...item} />

                    <view onClick={toggleLike} className='wdscbaozan'>
                   <image className='title-on' src={isLike === 1 ? baozan : weibaozan} />
                   <text className='title-on-text'>爆赞 {item.likeNum}</text>
                 </view>
                    </View>
                  </CouponMedia.Body>
                </CouponMedia>
              </CouponCard>
            </View>

          )
          // <view class='wrapper'>
          //   <view class='left-complete-one'   >
          //     <view className='title-image'>
          //       <image className='image-1' mode='scaleToFill' src={item.poster}></image>
          //       <image className='image-2' src={item.targetType === 'tourist' ? Attractions : food}></image>
          //     </view>
          //     <view className='title-content'>
          //       <view className='Pro-title'  >
          //         <view className='title-text'>{(item.title).toString().length > 25 ? (item.title).substring(0, 25) + '...' : (item.title)}</view>
          //       </view>
          //       <text className='title-money' >￥{formatPrice(item.averagePrice)}元</text>
          //       <view onClick={toggleLike}>
          //         <image className='title-on' src={isLike === 1 ? baozan : weibaozan} />
          //         <text className='title-on-text'>爆赞 {item.likeNum}</text>
          //       </view>
          //       <view className='title-position-on'>
          //         <image className='title-position' src={position} />
          //         <text className='title-position-image'>
          //           {
          //             item.areaPName === null ? item.areaName : (item.areaPName + '/' + item.areaName)
          //           }
          //         </text>
          //       </view>
          //     </view>
          //   </view>
          //   <view class='right-complete-two'>
          //     <view className='right-content' onClick={() => { targetType === 'tourist' ? Taro.navigateTo({ url: `/pages/details/mjDetails/sceneryDetails?id=${item.targetId}` }) : Taro.navigateTo({ url: `/pages/details/foodDetails/foodDetails?id=${item.targetId}` }) }}>
          //       <image className='right-image' src={SeeDetails} />
          //       <view className='right-title'>查看详情</view>
          //     </view>
          //   </view>
          // </view>

        }
      </View>
    </View>
  )
}
